@@ -269,6 +269,43 @@ class OrderStatus:
     Rejected = 'Rejected'
 
 
+class OptionsData(object):
+    def __init__(self, **kwargs):
+        self.Symbol: TradeSymbol
+        self.LastTradeTime: datetime
+        self.ServerTime: datetime
+        self.LTP: float
+        self.Bid: float
+        self.Ask: float
+        self.OpenInterest: float
+        self.OpenInterestChange: float
+
+        fill_obj(self, **kwargs)
+
+
+class OptionsGreeks(object):
+    def __init__(self, **kwargs):
+        self.Symbol: TradeSymbol = TradeSymbol()
+        self.Delta: float = 0.0
+        self.Theta: float = 0.0
+        self.Gamma: float = 0.0
+        self.Vega: float = 0.0
+        self.IV: float = 0.0
+        self.IVVWap: float = 0.0
+        self.Vanna: float = 0.0
+        self.Charm: float = 0.0
+        self.Speed: float = 0.0
+        self.Zomma: float = 0.0
+        self.Color: float = 0.0
+        self.Volga: float = 0.0
+        self.Veta: float = 0.0
+        self.ThetaGammaRatio: float = 0.0
+        self.ThetaVegaRatio: float = 0.0
+        self.DTR: float = 0.0
+
+        fill_obj(self, **kwargs)
+
+
 class PlaceOrderRequest(object):
     def __init__(self):
         self.Symbol = None
